@@ -10,7 +10,18 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+PLUGIN_NAME = 'ovs'
+
 OVS_VHOSTUSER_INTERFACE_TYPE = 'dpdkvhostuser'
+OVS_VHOSTUSER_CLIENT_INTERFACE_TYPE = 'dpdkvhostuserclient'
+OVS_VHOSTUSER_PREFIX = 'vhu'
 
 OVS_DATAPATH_SYSTEM = 'system'
 OVS_DATAPATH_NETDEV = 'netdev'
+
+OVS_DPDK_INTERFACE_TYPE = 'dpdk'
+
+# Neutron dead VLAN.
+DEAD_VLAN = 4095
+
+TRUNK_BR_PREFIX = 'tbr-'
