@@ -22,14 +22,12 @@
 import glob
 import os
 import re
-import sys
 
 from os_vif.internal.ip.api import ip as ip_lib
 from oslo_concurrency import processutils
 from oslo_log import log as logging
 from oslo_utils import excutils
 
-from vif_plug_ovs import constants
 from vif_plug_ovs import exception
 from vif_plug_ovs import privsep
 
@@ -45,6 +43,8 @@ VF_RE = re.compile(r"vf(\d+)", re.IGNORECASE)
 PF_RE = re.compile(r"pf(\d+)", re.IGNORECASE)
 # bus_info (bdf) contains <bus>:<dev>.<func>
 PF_FUNC_RE = re.compile(r"\.(\d+)", 0)
+# phys_port_name contains p##
+UPLINK_PORT_RE = re.compile(r"p(\d+)", re.IGNORECASE)
 
 _SRIOV_TOTALVFS = "sriov_totalvfs"
 NIC_NAME_LEN = 14
@@ -53,12 +53,7 @@ NIC_NAME_LEN = 14
 def _update_device_mtu(dev, mtu):
     if not mtu:
         return
-    if sys.platform != constants.PLATFORM_WIN32:
-        # Hyper-V with OVS does not support external programming of
-        # virtual interface MTUs via netsh or other Windows tools.
-        # When plugging an interface on Windows, we therefore skip
-        # programming the MTU and fallback to DHCP advertisement.
-        set_device_mtu(dev, mtu)
+    set_device_mtu(dev, mtu)
 
 
 @privsep.vif_plug.entrypoint
@@ -100,7 +95,7 @@ def _disable_ipv6(bridge):
        privsep context.
     """
     # NOTE(sean-k-mooney): os-vif disables ipv6 to ensure the Bridge
-    # does not aquire an ipv6 auto config or link local adress.
+    # does not acquire an ipv6 auto config or link local address.
     # This is required to prevent bug 1302080.
     # https://bugs.launchpad.net/neutron/+bug/1302080
     disv6 = ('/proc/sys/net/ipv6/conf/%s/disable_ipv6' %
@@ -145,7 +140,7 @@ def delete_bridge(bridge, dev):
         # Note(sean-k-mooney): this will detach all ports on
         # the bridge before deleting the bridge.
         ip_lib.delete(bridge, check_exit_code=[0, 2, 254])
-        # howver it will not set the detached interface down
+        # however it will not set the detached interface down
         # so we set the dev down if dev is not None and exists.
         if dev and ip_lib.exists(dev):
             set_interface_state(dev, "down")
@@ -239,46 +234,35 @@ def get_representor_port(pf_ifname, vf_num):
     VF number in the phys_port_name. That interface is the representor for
     the requested VF.
     """
-    pf_path = "/sys/class/net/%s" % pf_ifname
-    pf_sw_id_file = os.path.join(pf_path, "phys_switch_id")
 
     pf_sw_id = None
     try:
-        with open(pf_sw_id_file, 'r') as fd:
-            pf_sw_id = fd.readline().rstrip()
+        pf_sw_id = _get_phys_switch_id(pf_ifname)
     except (OSError, IOError):
         raise exception.RepresentorNotFound(ifname=pf_ifname, vf_num=vf_num)
 
-    pf_subsystem_file = os.path.join(pf_path, "subsystem")
+    pf_subsystem_file = "/sys/class/net/%s/subsystem" % pf_ifname
     try:
         devices = os.listdir(pf_subsystem_file)
     except (OSError, IOError):
         raise exception.RepresentorNotFound(ifname=pf_ifname, vf_num=vf_num)
 
-    for device in devices:
-        address_str, pf = get_function_by_ifname(device)
-        if pf:
-            continue
+    ifname_pf_func = _get_pf_func(pf_ifname)
+    if ifname_pf_func is None:
+        raise exception.RepresentorNotFound(ifname=pf_ifname, vf_num=vf_num)
 
-        device_path = "/sys/class/net/%s" % device
-        device_sw_id_file = os.path.join(device_path, "phys_switch_id")
+    for device in devices:
         try:
-            with open(device_sw_id_file, 'r') as fd:
-                device_sw_id = fd.readline().rstrip()
+            device_sw_id = _get_phys_switch_id(device)
+            if not device_sw_id or device_sw_id != pf_sw_id:
+                continue
         except (OSError, IOError):
             continue
 
-        if device_sw_id != pf_sw_id:
-            continue
-        device_port_name_file = (
-            os.path.join(device_path, 'phys_port_name'))
-
-        if not os.path.isfile(device_port_name_file):
-            continue
-
         try:
-            with open(device_port_name_file, 'r') as fd:
-                phys_port_name = fd.readline().rstrip()
+            phys_port_name = _get_phys_port_name(device)
+            if phys_port_name is None:
+                continue
         except (OSError, IOError):
             continue
 
@@ -287,9 +271,6 @@ def get_representor_port(pf_ifname, vf_num):
         # the PCI func number of pf_ifname.
         rep_parent_pf_func = _parse_pf_number(phys_port_name)
         if rep_parent_pf_func is not None:
-            ifname_pf_func = _get_pf_func(pf_ifname)
-            if ifname_pf_func is None:
-                continue
             if int(rep_parent_pf_func) != int(ifname_pf_func):
                 continue
 
@@ -321,9 +302,7 @@ def _get_sysfs_netdev_path(pci_addr, pf_interface):
 def _is_switchdev(netdev):
     """Returns True if a netdev has a readable phys_switch_id"""
     try:
-        sw_id_file = "/sys/class/net/%s/phys_switch_id" % netdev
-        with open(sw_id_file, 'r') as fd:
-            phys_switch_id = fd.readline().rstrip()
+        phys_switch_id = _get_phys_switch_id(netdev)
         if phys_switch_id != "" and phys_switch_id is not None:
             return True
     except (OSError, IOError):
@@ -344,12 +323,28 @@ def get_ifname_by_pci_address(pci_addr, pf_interface=False, switchdev=False):
     itself based on the argument of pf_interface.
     """
     dev_path = _get_sysfs_netdev_path(pci_addr, pf_interface)
-    # make the if statement later more readable
-    ignore_switchdev = not switchdev
     try:
-        for netdev in os.listdir(dev_path):
-            if ignore_switchdev or _is_switchdev(netdev):
-                return netdev
+        devices = os.listdir(dev_path)
+
+        # Return the first netdev in case of switchdev=False
+        if not switchdev:
+            return devices[0]
+        elif pf_interface:
+            fallback_netdev = None
+            for netdev in devices:
+                # Return the uplink representor in case of switchdev=True
+                if _is_switchdev(netdev):
+                    fallback_netdev = netdev if fallback_netdev is None \
+                        else fallback_netdev
+                    phys_port_name = _get_phys_port_name(netdev)
+                    if phys_port_name is not None and \
+                            UPLINK_PORT_RE.search(phys_port_name):
+                        return netdev
+
+            # Fallback to first switchdev netdev in case of switchdev=True
+            if fallback_netdev is not None:
+                return fallback_netdev
+
     except Exception:
         raise exception.PciDeviceNotFoundById(id=pci_addr)
     raise exception.PciDeviceNotFoundById(id=pci_addr)
@@ -389,3 +384,33 @@ def get_pf_pci_from_vf(vf_pci):
     """
     physfn_path = os.readlink("/sys/bus/pci/devices/%s/physfn" % vf_pci)
     return os.path.basename(physfn_path)
+
+
+def _get_phys_port_name(ifname):
+    """Get the interface name and return its phys_port_name
+
+    :param ifname: The interface name
+    :return: The phys_port_name of the given ifname
+    """
+    phys_port_name_path = "/sys/class/net/%s/phys_port_name" % ifname
+
+    if not os.path.isfile(phys_port_name_path):
+        return None
+
+    with open(phys_port_name_path, 'r') as fd:
+        return fd.readline().strip()
+
+
+def _get_phys_switch_id(ifname):
+    """Get the interface name and return its phys_switch_id
+
+    :param ifname: The interface name
+    :return: The phys_switch_id of the given ifname
+    """
+    phys_port_name_path = "/sys/class/net/%s/phys_switch_id" % ifname
+
+    if not os.path.isfile(phys_port_name_path):
+        return None
+
+    with open(phys_port_name_path, 'r') as fd:
+        return fd.readline().strip()
